<?php

namespace Drupal\pmfs\EventSubscriber;

use Drupal\Component\Utility\Crypt;
use Drupal\pmfs\Pmfs;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;

/**
 * Class Cookie.
 *
 * @package Drupal\pmfs\EventSubscriber
 */
class Cookie implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'kernel.request' => 'setCookie',
    ];
  }

  /**
   * Cookie handler of the module.
   *
   * @param mixed|\Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   Request event.
   */
  public function setCookie($event) {
    if (method_exists($event, 'getRequest')) {
      $request = $event->getRequest();
    }
    else {
      $request = \Drupal::request();
    }
    if (!$request->cookies->get(Pmfs::COOKIE)) {
      setcookie(Pmfs::COOKIE, Crypt::hashBase64(implode(',', $request->getClientIps())), ['path' => '/']);
    }
  }

}
